gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] branch master updated: add another interpreter command


From: gnunet
Subject: [taler-exchange] branch master updated: add another interpreter command to check incoming wire transfers
Date: Wed, 15 Jan 2020 15:44:29 +0100

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository exchange.

The following commit(s) were added to refs/heads/master by this push:
     new 19d9369f add another interpreter command to check incoming wire 
transfers
19d9369f is described below

commit 19d9369ff6df2e4bfd896cce5fcb2ae679402bc0
Author: Christian Grothoff <address@hidden>
AuthorDate: Wed Jan 15 15:44:24 2020 +0100

    add another interpreter command to check incoming wire transfers
---
 src/auditordb/plugin_auditordb_postgres.c          |   1 +
 src/exchange-tools/taler-exchange-keyup.c          |   2 +-
 src/exchange/taler-exchange-httpd_refresh_reveal.c |   6 +-
 src/exchangedb/plugin_exchangedb_postgres.c        |   1 +
 src/include/taler_testing_lib.h                    |  23 ++-
 src/lib/test_auditor_api.c                         |  12 +-
 src/lib/test_exchange_api.c                        |  19 +-
 src/lib/testing_api_cmd_bank_admin_check.c         | 221 +++++++++++++++++++++
 src/lib/testing_api_cmd_bank_check.c               |   2 +-
 src/lib/testing_api_cmd_status.c                   |   4 +
 10 files changed, 271 insertions(+), 20 deletions(-)

diff --git a/src/auditordb/plugin_auditordb_postgres.c 
b/src/auditordb/plugin_auditordb_postgres.c
index 0d16011f..d8e59b3d 100644
--- a/src/auditordb/plugin_auditordb_postgres.c
+++ b/src/auditordb/plugin_auditordb_postgres.c
@@ -1014,6 +1014,7 @@ postgres_get_session (void *cls)
   return session;
 }
 
+
 /**
  * Do a pre-flight check that we are not in an uncommitted transaction.
  * If we are, try to commit the previous transaction and output a warning.
diff --git a/src/exchange-tools/taler-exchange-keyup.c 
b/src/exchange-tools/taler-exchange-keyup.c
index 40801269..57782380 100644
--- a/src/exchange-tools/taler-exchange-keyup.c
+++ b/src/exchange-tools/taler-exchange-keyup.c
@@ -765,7 +765,7 @@ create_denomkey_issue (const struct CoinTypeParams *params,
   GNUNET_assert (NULL != dki->denom_priv.rsa_private_key);
   dki->denom_pub.rsa_public_key
     = GNUNET_CRYPTO_rsa_private_key_get_public (
-    dki->denom_priv.rsa_private_key);
+        dki->denom_priv.rsa_private_key);
   GNUNET_CRYPTO_rsa_public_key_hash (dki->denom_pub.rsa_public_key,
                                      &dki->issue.properties.denom_hash);
   dki->issue.properties.master = master_public_key;
diff --git a/src/exchange/taler-exchange-httpd_refresh_reveal.c 
b/src/exchange/taler-exchange-httpd_refresh_reveal.c
index 97e687ea..fb2602c6 100644
--- a/src/exchange/taler-exchange-httpd_refresh_reveal.c
+++ b/src/exchange/taler-exchange-httpd_refresh_reveal.c
@@ -771,9 +771,9 @@ handle_refresh_reveal_json (struct MHD_Connection 
*connection,
     {
       rctx->ev_sigs[i].rsa_signature
         = GNUNET_CRYPTO_rsa_sign_blinded (
-        rctx->dkis[i]->denom_priv.rsa_private_key,
-        rctx->rcds[i].coin_ev,
-        rctx->rcds[i].coin_ev_size);
+            rctx->dkis[i]->denom_priv.rsa_private_key,
+            rctx->rcds[i].coin_ev,
+            rctx->rcds[i].coin_ev_size);
       if (NULL == rctx->ev_sigs[i].rsa_signature)
       {
         GNUNET_break (0);
diff --git a/src/exchangedb/plugin_exchangedb_postgres.c 
b/src/exchangedb/plugin_exchangedb_postgres.c
index a657b405..25692445 100644
--- a/src/exchangedb/plugin_exchangedb_postgres.c
+++ b/src/exchangedb/plugin_exchangedb_postgres.c
@@ -1711,6 +1711,7 @@ postgres_get_session (void *cls)
   return session;
 }
 
+
 /**
  * Do a pre-flight check that we are not in an uncommitted transaction.
  * If we are, try to commit the previous transaction and output a warning.
diff --git a/src/lib/test_auditor_api.c b/src/lib/test_auditor_api.c
index eb381349..4909a183 100644
--- a/src/lib/test_auditor_api.c
+++ b/src/lib/test_auditor_api.c
@@ -231,12 +231,14 @@ run (void *cls,
     TALER_TESTING_cmd_check_bank_transfer
       ("check_bank_transfer-99c", ec.exchange_url,
       "EUR:0.08", bc.exchange_payto, bc.user43_payto),
+    TALER_TESTING_cmd_check_bank_admin_transfer
+      ("check_bank_transfer-aai-1",
+      "EUR:5.01", bc.user42_payto, bc.exchange_payto,
+      "FIXME"),
     TALER_TESTING_cmd_check_bank_transfer
-      ("check_bank_transfer-aai-1", ec.exchange_url,
-      "EUR:5.01", bc.user42_payto, bc.exchange_payto),
-    TALER_TESTING_cmd_check_bank_transfer
-      ("check_bank_transfer-aai-2", ec.exchange_url,
-      "EUR:5.01", bc.user42_payto, bc.exchange_payto),
+      ("check_bank_transfer-aai-2",
+      "EUR:5.01", bc.user42_payto, bc.exchange_payto,
+      "FIXME"),
 
     /* The following transactions got originated within
      * the "massive deposit confirms" batch.  */
diff --git a/src/lib/test_exchange_api.c b/src/lib/test_exchange_api.c
index 4a1f406f..5dc29770 100644
--- a/src/lib/test_exchange_api.c
+++ b/src/lib/test_exchange_api.c
@@ -351,17 +351,19 @@ run (void *cls,
       ("check_bank_transfer-99c", ec.exchange_url,
       "EUR:0.08", bc.exchange_payto, bc.user43_payto),
 
-    TALER_TESTING_cmd_check_bank_transfer
-      ("check_bank_transfer-aai-1", ec.exchange_url,
-      "EUR:5.01", bc.user42_payto, bc.exchange_payto),
+    TALER_TESTING_cmd_check_bank_admin_transfer
+      ("check_bank_transfer-aai-1",
+      "EUR:5.01", bc.user42_payto, bc.exchange_payto,
+      "FIXME"),
 
     /**
      * NOTE: the old test-suite had this "check bank transfer"
      * command with debit account == 424.
      */
-    TALER_TESTING_cmd_check_bank_transfer
+    TALER_TESTING_cmd_check_bank_admin_transfer
       ("check_bank_transfer-aai-2", ec.exchange_url,
-      "EUR:5.01", bc.user42_payto, bc.exchange_payto),
+      "EUR:5.01", bc.user42_payto, bc.exchange_payto,
+      "FIXME"),
 
     TALER_TESTING_cmd_check_bank_empty ("check_bank_empty"),
 
@@ -544,9 +546,10 @@ run (void *cls,
                                        "EUR:5",
                                        MHD_HTTP_OK),
 
-    TALER_TESTING_cmd_check_bank_transfer
-      ("check_bank_transfer-aai-3b", ec.exchange_url,
-      "EUR:5.01", bc.user42_payto, bc.exchange_payto),
+    TALER_TESTING_cmd_check_bank_admin_transfer
+      ("check_bank_transfer-aai-3b",
+      "EUR:5.01", bc.user42_payto, bc.exchange_payto,
+      "FIXME"),
 
 
     TALER_TESTING_cmd_deposit
diff --git a/src/lib/testing_api_cmd_bank_admin_check.c 
b/src/lib/testing_api_cmd_bank_admin_check.c
new file mode 100644
index 00000000..bfd089c9
--- /dev/null
+++ b/src/lib/testing_api_cmd_bank_admin_check.c
@@ -0,0 +1,221 @@
+/*
+  This file is part of TALER
+  Copyright (C) 2018-2020 Taler Systems SA
+
+  TALER is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as
+  published by the Free Software Foundation; either version 3, or
+  (at your option) any later version.
+
+  TALER is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public
+  License along with TALER; see the file COPYING.  If not, see
+  <http://www.gnu.org/licenses/>
+*/
+/**
+ * @file lib/testing_api_cmd_bank_admin_check.c
+ * @brief command to check if a particular admin/add-incoming transfer took
+ *        place.
+ * @author Christian Grothoff
+ */
+#include "platform.h"
+#include "taler_json_lib.h"
+#include <gnunet/gnunet_curl_lib.h>
+#include "exchange_api_handle.h"
+#include "taler_testing_lib.h"
+#include "taler_fakebank_lib.h"
+
+
+/**
+ * State for a "bank check" CMD.
+ */
+struct BankAdminCheckState
+{
+
+  /**
+   * Expected transferred amount.
+   */
+  const char *amount;
+
+  /**
+   * Expected debit bank account.
+   */
+  const char *debit_payto;
+
+  /**
+   * Expected credit bank account.
+   */
+  const char *credit_payto;
+
+  /**
+   * Command providing the reserve public key trait to use.
+   */
+  const char *reserve_pub_ref;
+
+  /**
+   * Interpreter state.
+   */
+  struct TALER_TESTING_Interpreter *is;
+
+};
+
+/**
+ * Run the command.
+ *
+ * @param cls closure.
+ * @param cmd the command to execute.
+ * @param is the interpreter state.
+ */
+static void
+check_bank_admin_transfer_run (void *cls,
+                               const struct TALER_TESTING_Command *cmd,
+                               struct TALER_TESTING_Interpreter *is)
+{
+  struct BankAdminCheckState *bcs = cls;
+  struct TALER_Amount amount;
+  char *debit_account;
+  char *credit_account;
+  const char *debit_payto;
+  const char *credit_payto;
+  const struct TALER_ReservePublicKeyP *reserve_pubp;
+  const struct TALER_TESTING_Command *cmd_ref;
+
+  cmd_ref
+    = TALER_TESTING_interpreter_lookup_command (is,
+                                                bcs->reserve_pub_ref);
+  if (NULL == cmd_ref)
+  {
+    GNUNET_break (0);
+    TALER_TESTING_interpreter_fail (is);
+    return;
+  }
+  if (GNUNET_OK !=
+      TALER_TESTING_get_trait_reserve_pub (cmd_ref,
+                                           0,
+                                           &reserve_pubp))
+  {
+    GNUNET_break (0);
+    TALER_LOG_ERROR ("Command reference fails to provide reserve public 
key\n");
+    TALER_TESTING_interpreter_fail (is);
+    return;
+  }
+  TALER_LOG_INFO ("Deposit reference NOT given\n");
+  debit_payto = bcs->debit_payto;
+  credit_payto = bcs->credit_payto;
+  if (GNUNET_OK !=
+      TALER_string_to_amount (bcs->amount,
+                              &amount))
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Failed to parse amount `%s' at %u\n",
+                bcs->amount,
+                is->ip);
+    TALER_TESTING_interpreter_fail (is);
+    return;
+  }
+  debit_account = TALER_xtalerbank_account_from_payto (debit_payto);
+  credit_account = TALER_xtalerbank_account_from_payto (credit_payto);
+  if (GNUNET_OK !=
+      TALER_FAKEBANK_check_credit (is->fakebank,
+                                   &amount,
+                                   debit_account,
+                                   credit_account,
+                                   reserve_pub))
+  {
+    GNUNET_break (0);
+    GNUNET_free (credit_account);
+    GNUNET_free (debit_account);
+    TALER_TESTING_interpreter_fail (is);
+    return;
+  }
+  GNUNET_free (credit_account);
+  GNUNET_free (debit_account);
+  TALER_TESTING_interpreter_next (is);
+}
+
+
+/**
+ * Free the state of a "bank check" CMD.
+ *
+ * @param cls closure.
+ * @param cmd the command which is being cleaned up.
+ */
+static void
+check_bank_admin_transfer_cleanup (void *cls,
+                                   const struct TALER_TESTING_Command *cmd)
+{
+  struct BankAdminCheckState *bcs = cls;
+
+  GNUNET_free (bcs);
+}
+
+
+/**
+ * Offer internal data from a "bank admin check" CMD state.
+ *
+ * @param cls closure.
+ * @param ret[out] result.
+ * @param trait name of the trait.
+ * @param index index number of the object to offer.
+ * @return #GNUNET_OK on success.
+ */
+static int
+check_bank_admin_transfer_traits (void *cls,
+                                  const void **ret,
+                                  const char *trait,
+                                  unsigned int index)
+{
+  struct BankAdminCheckState *bcs = cls;
+  struct TALER_TESTING_Trait traits[] = {
+    TALER_TESTING_trait_end ()
+  };
+
+  return TALER_TESTING_get_trait (traits,
+                                  ret,
+                                  trait,
+                                  index);
+}
+
+
+/**
+ * Make a "bank check" CMD.  It checks whether a particular wire transfer to
+ * the exchange (credit) has been made or not.
+ *
+ * @param label the command label.
+ * @param amount the amount expected to be transferred.
+ * @param debit_payto the account that gave money.
+ * @param credit_payto the account that received money.
+ * @param reserve_pub_ref command that provides the reserve public key to 
expect
+ * @return the command
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_check_bank_admin_transfer
+  (const char *label,
+  const char *amount,
+  const char *debit_payto,
+  const char *credit_payto,
+  const char *reserve_pub_ref)
+{
+  struct BankAdminCheckState *bcs;
+
+  bcs = GNUNET_new (struct BankAdminCheckState);
+  bcs->amount = amount;
+  bcs->debit_payto = debit_payto;
+  bcs->credit_payto = credit_payto;
+  bcs->reserve_pub_ref = reserve_pub_ref;
+  {
+    struct TALER_TESTING_Command cmd = {
+      .label = label,
+      .cls = bcs,
+      .run = &check_bank_admin_transfer_run,
+      .cleanup = &check_bank_admin_transfer_cleanup,
+      .traits = &check_bank_admin_transfer_traits
+    };
+
+    return cmd;
+  }
+}
diff --git a/src/lib/testing_api_cmd_bank_check.c 
b/src/lib/testing_api_cmd_bank_check.c
index 22a4e9bf..c06477a1 100644
--- a/src/lib/testing_api_cmd_bank_check.c
+++ b/src/lib/testing_api_cmd_bank_check.c
@@ -17,7 +17,7 @@
   <http://www.gnu.org/licenses/>
 */
 /**
- * @file exchange-lib/testing_api_cmd_bank_check.c
+ * @file lib/testing_api_cmd_bank_check.c
  * @brief command to check if a particular wire transfer took
  *        place.
  * @author Marcello Stanisci
diff --git a/src/lib/testing_api_cmd_status.c b/src/lib/testing_api_cmd_status.c
index 2da404fb..9d91e302 100644
--- a/src/lib/testing_api_cmd_status.c
+++ b/src/lib/testing_api_cmd_status.c
@@ -164,6 +164,10 @@ status_run (void *cls,
 
   /* NOTE: the following line might generate a ERROR log
    * statements, but it can be ignored.  */
+  /* FIXME: instead of having this logic here, any
+     command exporting a reserve_priv MUST also
+     export a reserve_pub, which would obsolete this
+     logic! */
   if (GNUNET_OK ==
       TALER_TESTING_get_trait_reserve_priv (create_reserve,
                                             0,

diff --git a/src/include/taler_testing_lib.h b/src/include/taler_testing_lib.h
index 9f638bd6..554106cd 100644
--- a/src/include/taler_testing_lib.h
+++ b/src/include/taler_testing_lib.h
@@ -1352,8 +1352,8 @@ TALER_TESTING_cmd_track_transfer (const char *label,
                                   const char *expected_wire_fee);
 
 /**
  * Make a "bank check" CMD.  It checks whether a
  * particular wire transfer has been made or not.
  *
  * @param label the command label.
  * @param exchange_base_url base url of the exchange involved in
@@ -1371,6 +1371,25 @@ TALER_TESTING_cmd_check_bank_transfer (const char *label,
                                        const char *credit_payto);
 
 
+/**
+ * Make a "bank check" CMD.  It checks whether a particular wire transfer to
+ * the exchange (credit) has been made or not.
+ *
+ * @param label the command label.
+ * @param amount the amount expected to be transferred.
+ * @param debit_payto the account that gave money.
+ * @param credit_payto the account that received money.
+ * @param reserve_pub_ref command that provides the reserve public key to 
expect
+ * @return the command
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_check_bank_admin_transfer (const char *label,
+                                             const char *amount,
+                                             const char *debit_payto,
+                                             const char *credit_payto,
+                                             const char *reserve_pub_ref);
+
+
 /**
  * Define a "bank check" CMD that takes the input
  * data from another CMD that offers it.
@@ -1352,8 +1352,8 @@ TALER_TESTING_cmd_track_transfer (const char *label,
 
 /**
- * Make a "bank check" CMD.  It checks whether a
- * particular wire transfer has been made or not.
+ * Make a "bank check" CMD.  It checks whether a particular wire transfer from
+ * the exchange (debit) has been made or not.
  *
  * @param label the command label.
-- 
To stop receiving notification emails like this one, please contact
address@hidden.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]